@@ -1,20 +1,20 @@
 # coding:utf-8
 import datetime
-from src.mf_driver import MFDriver
+from src.browser import Browser
 from src.utils.colors import Colors
 
 
 class AttendanceManager(object):
 
     def __init__(self):
-        self.mf_driver = MFDriver()
-        self.driver = self.mf_driver.driver
+        self.browser = Browser()
+        self.driver = self.browser.driver
 
     def login(self):
-        return self.mf_driver.login()
+        return self.browser.login()
 
     def clock_in(self):
-        if self.driver.current_url != self.mf_driver.MYPAGE_URL:
+        if self.driver.current_url != self.browser.MYPAGE_URL:
             print("Please login.")
 
         self.driver.find_element_by_class_name(
@@ -25,7 +25,7 @@ class AttendanceManager(object):
         Colors.print(Colors.GREEN, "DAKOKU successful. Good luck!")
 
     def clock_out(self):
-        if self.driver.current_url != self.mf_driver.MYPAGE_URL:
+        if self.driver.current_url != self.browser.MYPAGE_URL:
             print("Please login.")
 
         self.driver.find_element_by_class_name(
